@@ -453,7 +453,7 @@ class Method:
 
         # Assert timeout is int
         if timeout is not None:
-            if not isinstance(timeout, int) or type(timeout) == bool:
+            if not isinstance(timeout, int) or isinstance(timeout, bool):  # True isinstanceof int
                 raise TypeError("Timeouts can only be ints or None")
 
         # Resolve validation status
@@ -630,7 +630,7 @@ class Method:
                 self._validate_url(sorted_required_path_params)
 
             for k, v in sorted_required_path_params.items():
-                if path_params_safe_chars.get(k):
+                if path_params_safe_chars.get(k) is not None:
                     sorted_required_path_params[k] = quote(
                         str(v),
                         safe=path_params_safe_chars[k]
